"use strict";
/*!
 * Paradigm Framework - AngularJS Wrapper
 * Copyright (c) 2017 Miracle Devs, Inc
 * Licensed under MIT (https://github.com/MiracleDevs/Paradigm.Web.Shared/blob/master/LICENSE)
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ControllerBase = void 0;
const paradigm_ui_web_shared_1 = require("@miracledevs/paradigm-ui-web-shared");
const message_bus_service_1 = require("../services/message-bus.service");
const alert_service_1 = require("../services/alert.service");
const logging_service_1 = require("../services/logging.service");
const modal_service_1 = require("../services/modal.service");
const angular_service_1 = require("../services/angular.service");
const angular_base_controller_1 = require("./angular-base.controller");
class ControllerBase extends angular_base_controller_1.AngularControllerBase {
    constructor(scope, injector) {
        super(scope);
        this.injector = injector;
        this.initializeServices();
    }
    initializeServices() {
        this.logger = this.getService(logging_service_1.LoggingService);
        this.alertService = this.getService(alert_service_1.AlertService);
        this.stateService = this.getService(angular_service_1.AngularServices.state);
        this.messageBus = this.getService(message_bus_service_1.MessageBus);
        this.translator = this.getService(angular_service_1.AngularServices.translate);
        this.messageBusTokens = new paradigm_ui_web_shared_1.ArrayList();
    }
    onDestroy() {
        super.onDestroy();
        this.unregisterAllMessages();
    }
    getService(service) {
        return this.injector.get(service);
    }
    open(controller, parameters, staticDialog, keyboard) {
        return this.getService(modal_service_1.ModalService).open(controller, parameters, staticDialog, keyboard);
    }
    translate(key) {
        return this.translator.instant(key);
    }
    call(call, success, loading, fail) {
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(loading))
            loading(true);
        call()
            .then(result => {
            if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(loading))
                loading(false);
            if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(success))
                success(result);
        })
            .catch(error => {
            if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(loading))
                loading(false);
            if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(fail))
                fail(error);
            this.handleException(error);
        });
    }
    showErrors(messages) {
        if (messages.length === 0)
            return;
        for (let i = 0; i < messages.length; i++) {
            this.showError(messages[i]);
        }
    }
    showWarnings(messages) {
        if (messages.length === 0)
            return;
        for (let i = 0; i < messages.length; i++) {
            this.showWarning(messages[i]);
        }
    }
    showError(message) {
        this.alertService.addError(message);
    }
    showWarning(message) {
        this.alertService.addWarning(message);
    }
    showMessage(message) {
        this.alertService.addMessage(message);
    }
    handleException(ex) {
        if (paradigm_ui_web_shared_1.ObjectExtensions.isNull(ex))
            return;
        // if ex.data is not null, it's probably a
        // an http promise exception.
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(ex.data))
            ex = ex.data;
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(ex.message)) {
            this.showError(ex.message);
        }
        else if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(ex.Message)) {
            this.showError(ex.Message);
        }
        else if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(ex.ExceptionMessage)) {
            this.showError(ex.ExceptionMessage);
        }
        else if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(ex.error) && !paradigm_ui_web_shared_1.ObjectExtensions.isNull(ex.error.message)) {
            this.showError(ex.error.message);
        }
    }
    changeState(state, params, reload = false) {
        return this.stateService.go(state, params, { reload: reload });
    }
    registerMessage(messageType, handler) {
        var token = this.messageBus.register(messageType, handler);
        this.messageBusTokens.add(token);
        return token;
    }
    sendMessage(message, token) {
        return this.messageBus.send(message);
    }
    unregisterMessage(token) {
        if (!this.messageBusTokens.any(x => x.guid === token.guid))
            throw new Error("Can not unregister a token registered outside this controller.");
        this.messageBus.unregister(token);
        this.messageBusTokens.removeAll(x => x.guid === token.guid);
    }
    unregisterAllMessages() {
        this.messageBusTokens.forEach(x => this.messageBus.unregister(x));
    }
}
exports.ControllerBase = ControllerBase;
//# sourceMappingURL=base.controller.js.map