"use strict";
/*!
 * Paradigm Framework - AngularJS Wrapper
 * Copyright (c) 2017 Miracle Devs, Inc
 * Licensed under MIT (https://github.com/MiracleDevs/Paradigm.Web.Shared/blob/master/LICENSE)
 */
Object.defineProperty(exports, "__esModule", { value: true });
const paradigm_ui_web_shared_1 = require("@miracledevs/paradigm-ui-web-shared");
const mock_service_spec_1 = require("../mocks/mock.service.spec");
const angular_1 = require("angular");
const framework_module_1 = require("../framework.module");
const angular_service_1 = require("../services/angular.service");
const alert_service_1 = require("../services/alert.service");
const logging_service_1 = require("../services/logging.service");
const mock_controller_spec_1 = require("../mocks/mock.controller.spec");
const injector_service_1 = require("../services/injector.service");
const registrable_1 = require("../decorators/registrable");
describe("MockController", () => {
    var injector;
    var rootScopeService;
    var controllerService;
    var alertService;
    var testService;
    var logger = new mock_service_spec_1.TestLoggingService();
    beforeEach(() => {
        // create a new framework module with all the configuration.
        angular_1.mock.module(framework_module_1.FrameworkModule.instance.getModuleName());
        // inject a dummy logging service to prevent undesired logging.
        angular_1.mock.module($provide => {
            $provide.value((0, registrable_1.getRegistrableName)(logging_service_1.LoggingService), logger);
            var testPromiseService = mock_service_spec_1.TestPromiseService[registrable_1.registrableMetadataKey].dependencies.slice(0);
            testPromiseService.push(mock_service_spec_1.TestPromiseService[registrable_1.registrableMetadataKey].factory);
            $provide.factory("TestPromiseService", testPromiseService);
        });
    });
    // prepare base services and classes.
    beforeEach(inject(($injector) => {
        injector = injector_service_1.InjectorService.factory($injector);
        rootScopeService = injector.get(angular_service_1.AngularServices.rootScope);
        controllerService = injector.get(angular_service_1.AngularServices.controller);
        alertService = injector.get(alert_service_1.AlertService);
        testService = injector.get(mock_service_spec_1.TestPromiseService);
    }));
    function getController() {
        return controllerService(mock_controller_spec_1.MockController, { scope: rootScopeService.$new(false, rootScopeService), injector: injector, testService: testService });
    }
    describe("controller construction", () => {
        it("shuld instantiate test controller", () => {
            var controller = getController();
            expect(controller).not.toBeNull();
            expect(controller.numberResult).toBe(0);
            expect(controller.booleanResult).toBe(false);
            expect(controller.stringResult).toBe("");
            expect(controller.dateResult).toBe(null);
            expect(controller.objectResult).toBe(null);
            expect(controller.arrayResult).toBe(null);
            expect(controller.rejectionReason).toBe("");
            expect(controller.loading).toBe(false);
        });
    });
    describe("base methods", () => {
        it("should have base services", () => {
            var controller = getController();
            expect(controller.getAlertService()).not.toBeNull();
            expect(controller.getStateService()).not.toBeNull();
            expect(controller.getMessageBus()).not.toBeNull();
            expect(controller.getTranslator()).not.toBeNull();
            expect(controller.getLogger()).not.toBeNull();
            expect(controller.getMessageBusTokens()).not.toBeNull();
        });
        /*it("should get services", () => expect(ObjectExtensions.getTypeName(getController().retrieveService<ITestPromiseService>("TestPromiseService"))).toBe("TestPromiseService"));*/
    });
    describe("promise methods", () => {
        it("should respond number promises", () => {
            var controller = getController();
            controller.testNumbers();
            rootScopeService.$apply();
            expect(controller.numberResult).toBe(testService.numberResult);
        });
        it("should respond boolean promises", () => {
            var controller = getController();
            controller.testBooleans();
            rootScopeService.$apply();
            expect(controller.booleanResult).toBe(testService.booleanResult);
        });
        it("should respond string promises", () => {
            var controller = getController();
            controller.testStrings();
            rootScopeService.$apply();
            expect(controller.stringResult).toBe(testService.stringResult);
        });
        it("should respond date promises", () => {
            var controller = getController();
            controller.testDates();
            rootScopeService.$apply();
            expect(controller.dateResult).toBe(testService.dateResult);
        });
        it("should respond object promises", () => {
            var controller = getController();
            controller.testObjects();
            rootScopeService.$apply();
            expect(paradigm_ui_web_shared_1.ObjectExtensions.isEqualTo(controller.objectResult, testService.objectResult)).toBe(true);
        });
        it("should respond array promises", () => {
            var controller = getController();
            controller.testArrays();
            rootScopeService.$apply();
            expect(paradigm_ui_web_shared_1.ObjectExtensions.isEqualTo(controller.arrayResult, testService.arrayResult)).toBe(true);
        });
        it("should reject promises", () => {
            var controller = getController();
            controller.testRejection();
            rootScopeService.$apply();
            expect(controller.rejectionReason).toBe(testService.rejectionReason);
        });
    });
});
//# sourceMappingURL=base.controller.spec.js.map