"use strict";
/*!
 * Paradigm Framework - AngularJS Wrapper
 * Copyright (c) 2017 Miracle Devs, Inc
 * Licensed under MIT (https://github.com/MiracleDevs/Paradigm.Web.Shared/blob/master/LICENSE)
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.DirectiveBase = void 0;
const paradigm_ui_web_shared_1 = require("@miracledevs/paradigm-ui-web-shared");
const registrable_1 = require("../decorators/registrable");
const $ = require("jquery");
class DirectiveBase {
    constructor() {
        var decorator = this.constructor[registrable_1.registrableMetadataKey];
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(decorator)) {
            for (var key in decorator) {
                if (decorator.hasOwnProperty(key)) {
                    var destinationKey = key === "bindings" ? "scope" : key;
                    this[destinationKey] = decorator[key];
                }
            }
        }
        this.link = (s, e, a, c, t) => {
            var element = $(e);
            this.onInit(s, element, a, c, t);
            s.$on("$destroy", () => this.onDestroy(s, element, a, c, t));
        };
    }
    onDestroy(scope, instanceElement, instanceAttributes, controller, transclude) {
        instanceElement.remove();
    }
    call(call, success, loading, fail) {
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(loading))
            loading(true);
        call()
            .then(result => {
            if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(loading))
                loading(false);
            if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(success)) {
                success(result);
            }
        })
            .catch(error => {
            if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(loading))
                loading(false);
            if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(fail))
                fail(error);
        });
    }
    getOptions(instanceAttributes, optionsParameter) {
        if (paradigm_ui_web_shared_1.StringExtensions.isNullOrWhiteSpace(instanceAttributes[optionsParameter]))
            return null;
        return JSON.parse(instanceAttributes[optionsParameter]);
    }
    tryGetInt(options, instanceAttributes, optionFrom, optionTo) {
        optionTo = optionTo || optionFrom;
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(instanceAttributes[optionFrom]))
            options[optionTo] = parseInt(instanceAttributes[optionFrom], 10);
        return options[optionTo];
    }
    tryGetNumber(options, instanceAttributes, optionFrom, optionTo) {
        optionTo = optionTo || optionFrom;
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(instanceAttributes[optionFrom]))
            options[optionTo] = parseFloat(instanceAttributes[optionFrom]);
        return options[optionTo];
    }
    tryGetDate(options, instanceAttributes, optionFrom, optionTo) {
        optionTo = optionTo || optionFrom;
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(instanceAttributes[optionFrom]))
            options[optionTo] = new Date(instanceAttributes[optionFrom]);
        return options[optionTo];
    }
    tryGetBoolean(options, instanceAttributes, optionFrom, optionTo) {
        optionTo = optionTo || optionFrom;
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(instanceAttributes[optionFrom])) {
            const value = instanceAttributes[optionFrom].toLowerCase();
            options[optionTo] = value === "yes" || value === "true" || value === "1";
        }
        return options[optionTo];
    }
    tryGet(options, instanceAttributes, optionFrom, optionTo) {
        optionTo = optionTo || optionFrom;
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(instanceAttributes[optionFrom]))
            options[optionTo] = instanceAttributes[optionFrom];
        return options[optionTo];
    }
}
exports.DirectiveBase = DirectiveBase;
//# sourceMappingURL=base.directive.js.map