"use strict";
/*!
 * Paradigm UI Web
 * Copyright (c) 2017 Miracle Devs, Inc
 * Licensed under MIT (https://gitlab.com/miracledevs-paradigm/ui-web-angularjs/blob/master/LICENSE)
 */
var CommentAreaDirective_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommentAreaDirective = void 0;
const tslib_1 = require("tslib");
const directive_1 = require("../decorators/directive");
const base_directive_1 = require("./base.directive");
const paradigm_ui_web_shared_1 = require("@miracledevs/paradigm-ui-web-shared");
const $ = require("jquery");
let CommentAreaDirective = CommentAreaDirective_1 = class CommentAreaDirective extends base_directive_1.DirectiveBase {
    onInit(scope, instanceElement, instanceAttributes, controller, transclude) {
        var options = {};
        this.tryGetNumber(options, instanceAttributes, "defaultHeight");
        this.tryGetNumber(options, instanceAttributes, "maxSize");
        this.tryGet(options, instanceAttributes, "maxSizeField");
        this.tryGet(options, instanceAttributes, "maxSizeText");
        this.tryGetBoolean(options, instanceAttributes, "resize");
        this.tryGetBoolean(options, instanceAttributes, "showAlways");
        this.tryGetBoolean(options, instanceAttributes, "restrictEntry");
        this.tryGet(options, instanceAttributes, "negativeClass");
        if (options.restrictEntry) {
            instanceElement.on("keydown", event => this.restrictEntry(event, options, instanceElement, false));
            instanceElement.on("keypress", event => this.restrictEntry(event, options, instanceElement, true));
            instanceElement.on("keyup", event => this.restrictEntry(event, options, instanceElement, false));
            scope.$watch(() => scope["ngModel"], () => this.restrictEntry(null, options, instanceElement, false));
        }
        else {
            instanceElement.on("keypress", () => this.showCharacterLeft(options, instanceElement, true));
            scope.$watch(() => scope["ngModel"], () => this.showCharacterLeft(options, instanceElement, false));
        }
    }
    restrictEntry(event, options, element, cancel) {
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(options.maxSize)) {
            const value = element.val();
            const length = value.length;
            let available = options.maxSize - length;
            if (available < 0)
                available = -1;
            if (available === -1) {
                if (cancel) {
                    event.stopPropagation();
                    event.preventDefault();
                }
                element.val(value.substr(0, options.maxSize));
                available = 0;
            }
            if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(options.maxSizeText)) {
                $(options.maxSizeField).text(available === options.maxSize && !options.showAlways ? "" : paradigm_ui_web_shared_1.StringExtensions.format(options.maxSizeText, available));
            }
            if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(options.resize) && options.resize) {
                this.checkSize(options, element);
            }
        }
    }
    showCharacterLeft(options, element, cancel) {
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(options.maxSize)) {
            const value = element.val();
            const length = value.length;
            const available = options.maxSize - length;
            if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(options.maxSizeText)) {
                const field = $(options.maxSizeField);
                if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(options.negativeClass)) {
                    if (available < 0)
                        field.addClass(options.negativeClass);
                    else
                        field.removeClass(options.negativeClass);
                }
                $(options.maxSizeField).text(available === options.maxSize && !options.showAlways ? "" : paradigm_ui_web_shared_1.StringExtensions.format(options.maxSizeText, available));
            }
            if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(options.resize) && options.resize) {
                this.checkSize(options, element);
            }
        }
        else {
            if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(options.resize) && options.resize) {
                this.checkSize(options, element);
            }
        }
    }
    checkSize(options, element) {
        const control = element[0];
        const defaultHeight = options.defaultHeight || 0;
        control.style.height = "1px";
        if (control.scrollHeight > control.clientHeight) {
            if (control.scrollHeight > defaultHeight)
                control.style.height = control.scrollHeight + "px";
            else
                control.style.height = defaultHeight + "px";
        }
        else if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(options.defaultHeight)) {
            control.style.height = defaultHeight + "px";
        }
    }
    static factory() {
        return new CommentAreaDirective_1();
    }
};
CommentAreaDirective = CommentAreaDirective_1 = (0, tslib_1.__decorate)([
    (0, directive_1.Directive)({
        name: "commentArea",
        require: "ngModel",
        bindings: {
            ngModel: "=",
        },
    })
], CommentAreaDirective);
exports.CommentAreaDirective = CommentAreaDirective;
//# sourceMappingURL=comment-area.directive.js.map