"use strict";
/*!
 * Paradigm Framework - AngularJS Wrapper
 * Copyright (c) 2017 Miracle Devs, Inc
 * Licensed under MIT (https://github.com/MiracleDevs/Paradigm.Web.Shared/blob/master/LICENSE)
 */
var HorizontalScrollerDirective_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.HorizontalScrollerInstance = exports.HorizontalScrollerDirective = void 0;
const tslib_1 = require("tslib");
const base_directive_1 = require("./base.directive");
const directive_1 = require("../decorators/directive");
const angular_service_1 = require("../services/angular.service");
const paradigm_ui_web_shared_1 = require("@miracledevs/paradigm-ui-web-shared");
const $ = require("jquery");
let HorizontalScrollerDirective = HorizontalScrollerDirective_1 = class HorizontalScrollerDirective extends base_directive_1.DirectiveBase {
    constructor(interpolate) {
        super();
        this.interpolate = interpolate;
    }
    onInit(scope, instanceElement, instanceAttributes, controller, transclude) {
        const options = {};
        options.element = instanceElement;
        this.tryGet(options, instanceAttributes, "container");
        this.tryGet(options, instanceAttributes, "content");
        this.tryGet(options, instanceAttributes, "leftArrow");
        this.tryGet(options, instanceAttributes, "rightArrow");
        this.tryGetNumber(options, instanceAttributes, "speed");
        this.tryGetNumber(options, instanceAttributes, "friction");
        this.tryGetNumber(options, instanceAttributes, "fps");
        this.tryGetNumber(options, instanceAttributes, "minVelocity");
        if (paradigm_ui_web_shared_1.StringExtensions.isNullOrWhiteSpace(options.container) ||
            paradigm_ui_web_shared_1.StringExtensions.isNullOrWhiteSpace(options.content) ||
            paradigm_ui_web_shared_1.StringExtensions.isNullOrWhiteSpace(options.leftArrow) ||
            paradigm_ui_web_shared_1.StringExtensions.isNullOrWhiteSpace(options.rightArrow))
            return;
        instanceElement[0]["scrollerInstance"] = new HorizontalScrollerInstance(options);
        scope.$watch(() => instanceElement[0].innerHTML, () => instanceElement[0]["scrollerInstance"].enableScroll());
    }
    onDestroy(scope, instanceElement, instanceAttributes, controller, transclude) {
        instanceElement[0]["scrollerInstance"].dispose();
        super.onDestroy(scope, instanceElement, instanceAttributes, controller, transclude);
    }
    static factory(interpolate) {
        return new HorizontalScrollerDirective_1(interpolate);
    }
};
HorizontalScrollerDirective = HorizontalScrollerDirective_1 = (0, tslib_1.__decorate)([
    (0, directive_1.Directive)({
        name: "horizontalScroller",
        dependencies: [angular_service_1.AngularServices.interpolate],
    })
], HorizontalScrollerDirective);
exports.HorizontalScrollerDirective = HorizontalScrollerDirective;
class HorizontalScrollerInstance {
    constructor(options) {
        this.element = $(options.element);
        this.container = this.element.find(options.container);
        this.content = this.element.find(options.content);
        this.leftArrow = this.element.find(options.leftArrow);
        this.rightArrow = this.element.find(options.rightArrow);
        this.position = 0;
        this.velocity = 0;
        this.speed = options.speed || 140;
        this.friction = options.friction || 0.95;
        this.millisecondsPerFrame = 1000 / (options.fps || 60);
        this.minVelocity = options.minVelocity || 10;
        this.enableScroll();
        $(window).on("resize", () => this.enableScroll());
        this.leftArrow.on("mousedown touchstart", () => this.moveLeft());
        this.leftArrow.on("mouseup mouseleave touchend touchcancel", () => (this.pressing = false));
        this.rightArrow.on("mousedown touchstart", () => this.moveRight());
        this.rightArrow.on("mouseup mouseleave touchend touchcancel", () => (this.pressing = false));
    }
    enableScroll() {
        const wContainer = this.container.width();
        const wContent = this.content.width();
        if (wContent < wContainer) {
            this.leftArrow.css("display", "none");
            this.rightArrow.css("display", "none");
            this.position = 0;
        }
        else {
            this.leftArrow.css("display", "inline-block");
            this.rightArrow.css("display", "inline-block");
        }
        this.checkConstraints();
        this.applyPosition();
    }
    applyPosition() {
        const translate = `translate(${this.position}px, 0)`;
        const translate3D = `translate3d(${this.position}px, 0, 0)`;
        this.content.css({
            "-ms-transform": translate,
            "-moz-transform": translate3D,
            "-webkit-transform": translate3D,
            transform: translate3D,
        });
    }
    checkConstraints() {
        const wContainer = this.container.width();
        const wContent = this.content.width();
        const minMovement = wContainer - wContent;
        if (wContent <= wContainer || this.position >= 0)
            this.position = 0;
        if (wContent >= wContainer && this.position <= minMovement)
            this.position = minMovement;
    }
    killInterval() {
        if (paradigm_ui_web_shared_1.ObjectExtensions.isNull(this.intervalId))
            return;
        window.clearInterval(this.intervalId);
    }
    getMilliseconds() {
        return new Date().getTime();
    }
    moveLeft() {
        this.pressing = true;
        this.direction = 1;
        this.lastTime = this.getMilliseconds();
        this.killInterval();
        this.intervalId = window.setInterval(() => this.move(), this.millisecondsPerFrame);
    }
    moveRight() {
        this.pressing = true;
        this.direction = -1;
        this.lastTime = this.getMilliseconds();
        this.killInterval();
        this.intervalId = window.setInterval(() => this.move(), this.millisecondsPerFrame);
    }
    move() {
        const deltaTime = (this.getMilliseconds() - this.lastTime) / 1000;
        if (this.pressing) {
            this.velocity = this.speed;
        }
        this.velocity *= this.friction;
        this.position = this.position + this.direction * this.velocity * deltaTime;
        this.checkConstraints();
        this.applyPosition();
        if (this.velocity <= this.minVelocity) {
            this.killInterval();
        }
        this.lastTime = this.getMilliseconds();
    }
    dispose() {
        this.container.remove();
        this.content.remove();
        this.leftArrow.remove();
        this.rightArrow.remove();
    }
}
exports.HorizontalScrollerInstance = HorizontalScrollerInstance;
//# sourceMappingURL=horizontal-scroller.directive.js.map