"use strict";
/*!
 * Paradigm Framework - AngularJS Wrapper
 * Copyright (c) 2017 Miracle Devs, Inc
 * Licensed under MIT (https://github.com/MiracleDevs/Paradigm.Web.Shared/blob/master/LICENSE)
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.FrameworkModule = void 0;
const base_module_1 = require("./base.module");
const add_class_directive_1 = require("./directives/add-class.directive");
const alert_directive_1 = require("./directives/alert.directive");
const background_image_directive_1 = require("./directives/background-image.directive");
const comment_area_directive_1 = require("./directives/comment-area.directive");
const convert_to_number_directive_1 = require("./directives/convert-to-number.directive");
const date_time_picker_directive_1 = require("./directives/date-time-picker.directive");
const file_button_directive_1 = require("./directives/file-button.directive");
const file_drag_and_drop_directive_1 = require("./directives/file-drag-and-drop.directive");
const focus_when_directive_1 = require("./directives/focus-when.directive");
const format_as_number_directive_1 = require("./directives/format-as-number.directive");
const full_select_directive_1 = require("./directives/full-select.directive");
const horizontal_scroller_directive_1 = require("./directives/horizontal-scroller.directive");
const keyboard_listener_directive_1 = require("./directives/keyboard-listener.directive");
const md_ui_sref_active_directive_1 = require("./directives/md-ui-sref-active.directive");
const on_keyboard_directive_1 = require("./directives/on-keyboard.directive");
const prevent_event_if_directive_1 = require("./directives/prevent-event-if.directive");
const remove_class_directive_1 = require("./directives/remove-class.directive");
const scroll_to_bottom_directive_1 = require("./directives/scroll-to-bottom.directive");
const scroll_toggle_class_directive_1 = require("./directives/scroll-toggle-class.directive");
const scroll_to_top_directive_1 = require("./directives/scroll-to-top.directive");
const select_toggle_class_directive_1 = require("./directives/select-toggle-class.directive");
const toggle_class_directive_1 = require("./directives/toggle-class.directive");
const toggle_class_on_click_directive_1 = require("./directives/toggle-class-on-click.directive");
const tooltip_directive_1 = require("./directives/tooltip.directive");
const alert_service_1 = require("./services/alert.service");
const async_resource_service_1 = require("./services/async-resource.service");
const date_service_1 = require("./services/date.service");
const exception_service_1 = require("./services/exception.service");
const file_management_service_1 = require("./services/file-management.service");
const geolocation_service_1 = require("./services/geolocation.service");
const key_processor_service_1 = require("./services/key-processor.service");
const message_bus_service_1 = require("./services/message-bus.service");
const modal_service_1 = require("./services/modal.service");
const logging_service_1 = require("./services/logging.service");
const url_service_1 = require("./services/url.service");
const injector_service_1 = require("./services/injector.service");
class FrameworkModule extends base_module_1.ModuleBase {
    constructor() {
        if (FrameworkModule.internalInstance != null)
            throw new Error("The program does not allow more than one instance of the ModuleBase.");
        super();
        FrameworkModule.internalInstance = this;
        this.logger.debug("creating application");
    }
    static get instance() {
        return FrameworkModule.internalInstance;
    }
    getModuleName() {
        return "miracledevs-framework";
    }
    register() {
        this.registerLoggingService(logging_service_1.LoggingService);
        this.registerServices([
            injector_service_1.InjectorService,
            alert_service_1.AlertService,
            async_resource_service_1.AsyncResourceService,
            date_service_1.DateService,
            exception_service_1.ExceptionService,
            file_management_service_1.FileManagementService,
            geolocation_service_1.GeolocationService,
            key_processor_service_1.KeyProcessorService,
            logging_service_1.LoggingService,
            message_bus_service_1.MessageBus,
            modal_service_1.ModalService,
            url_service_1.UrlService,
        ]);
        this.registerDirectives([
            add_class_directive_1.AddClassDirective,
            alert_directive_1.AlertDirective,
            background_image_directive_1.BackgroundImageDirective,
            comment_area_directive_1.CommentAreaDirective,
            convert_to_number_directive_1.ConvertToNumberDirective,
            date_time_picker_directive_1.DateTimePickerDirective,
            file_button_directive_1.FileButtonDirective,
            file_drag_and_drop_directive_1.FileDragAndDropDirective,
            focus_when_directive_1.FocusWhenDirective,
            format_as_number_directive_1.FormatAsNumberDirective,
            full_select_directive_1.FullSelectDirective,
            horizontal_scroller_directive_1.HorizontalScrollerDirective,
            keyboard_listener_directive_1.KeyboardListenerDirective,
            md_ui_sref_active_directive_1.MdUiSrefActiveDirective,
            on_keyboard_directive_1.OnKeyboardDirective,
            prevent_event_if_directive_1.PreventEventIfDirective,
            remove_class_directive_1.RemoveClassDirective,
            scroll_to_bottom_directive_1.ScrollToBottomDirective,
            scroll_toggle_class_directive_1.ScrollToggleClassDirective,
            scroll_to_top_directive_1.ScrollToTopDirective,
            select_toggle_class_directive_1.SelectToggleClassDirective,
            toggle_class_directive_1.ToggleClassDirective,
            toggle_class_on_click_directive_1.ToggleClassOnClickDirective,
            tooltip_directive_1.TooltipDirective,
        ]);
    }
    getModuleDependencies() {
        return ["ui.router", "ngAnimate", "pascalprecht.translate"];
    }
}
exports.FrameworkModule = FrameworkModule;
FrameworkModule.internalInstance = new FrameworkModule();
//# sourceMappingURL=framework.module.js.map