"use strict";
/*!
 * Paradigm Framework - AngularJS Wrapper
 * Copyright (c) 2017 Miracle Devs, Inc
 * Licensed under MIT (https://github.com/MiracleDevs/Paradigm.Web.Shared/blob/master/LICENSE)
 */
var AlertService_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.Alert = exports.AlertType = exports.AlertService = void 0;
const tslib_1 = require("tslib");
const base_service_1 = require("./base.service");
const service_1 = require("../decorators/service");
const paradigm_ui_web_shared_1 = require("@miracledevs/paradigm-ui-web-shared");
const logging_service_1 = require("./logging.service");
let AlertService = AlertService_1 = class AlertService extends base_service_1.ServiceBase {
    constructor(logger) {
        super();
        this.logger = logger;
        this.alerts = new paradigm_ui_web_shared_1.ArrayList();
    }
    add(alertType, message) {
        this.alerts.add(new Alert(alertType, message));
        this.logger.log(message, AlertService_1.getLogType(alertType));
    }
    addError(message) {
        this.add(AlertType.Error, message);
    }
    addWarning(message) {
        this.add(AlertType.Warning, message);
    }
    addMessage(message) {
        this.add(AlertType.Message, message);
    }
    remove(index) {
        if (index instanceof Alert)
            this.alerts.remove(index);
        else
            this.alerts.removeAt(index);
    }
    get(index) {
        return this.alerts.get(index);
    }
    getAlerts() {
        return this.alerts;
    }
    clear() {
        this.alerts.clear();
    }
    static getLogType(alertType) {
        switch (alertType) {
            case AlertType.Message:
                return logging_service_1.LogType.Information;
            case AlertType.Warning:
                return logging_service_1.LogType.Warning;
            case AlertType.Error:
                return logging_service_1.LogType.Error;
        }
        return logging_service_1.LogType.Information;
    }
    static factory(logger) {
        return new AlertService_1(logger);
    }
};
AlertService = AlertService_1 = (0, tslib_1.__decorate)([
    (0, service_1.Service)({
        name: "$pd-alertService",
        dependencies: [logging_service_1.LoggingService],
    })
], AlertService);
exports.AlertService = AlertService;
var AlertType;
(function (AlertType) {
    AlertType[AlertType["Message"] = 2] = "Message";
    AlertType[AlertType["Warning"] = 3] = "Warning";
    AlertType[AlertType["Error"] = 4] = "Error";
})(AlertType = exports.AlertType || (exports.AlertType = {}));
class Alert {
    constructor(alertType, message) {
        this.alertType = alertType;
        this.innerMessage = message;
    }
    get type() {
        return this.alertType;
    }
    get typeName() {
        return Alert.getTypeName(this.alertType);
    }
    get message() {
        return this.innerMessage;
    }
    static getTypeName(alertType) {
        switch (alertType) {
            case AlertType.Message:
                return "message";
            case AlertType.Warning:
                return "warning";
            case AlertType.Error:
                return "error";
            default:
                return "unknown";
        }
    }
}
exports.Alert = Alert;
//# sourceMappingURL=alert.service.js.map