"use strict";
/*!
 * Paradigm Framework - AngularJS Wrapper
 * Copyright (c) 2017 Miracle Devs, Inc
 * Licensed under MIT (https://github.com/MiracleDevs/Paradigm.Web.Shared/blob/master/LICENSE)
 */
var FileManagementService_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileManagementService = void 0;
const tslib_1 = require("tslib");
const service_1 = require("../decorators/service");
const base_service_1 = require("./base.service");
const angular_service_1 = require("./angular.service");
const paradigm_ui_web_shared_1 = require("@miracledevs/paradigm-ui-web-shared");
let FileManagementService = FileManagementService_1 = class FileManagementService extends base_service_1.ServiceBase {
    constructor(timeout) {
        super();
        this.timeout = timeout;
    }
    read(file, completed, progress, error) {
        const reader = new FileReader();
        reader.onload = e => this.timeout(() => completed(file, btoa(e.target["result"])));
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(progress))
            reader.onprogress = e => {
                if (e.lengthComputable) {
                    const percentLoaded = Math.round((e.loaded / e.total) * 100);
                    progress(percentLoaded);
                }
            };
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(error)) {
            reader.onabort = e => error(this.getError(e));
            reader.onerror = e => error(this.getError(e));
        }
        reader.readAsBinaryString(file);
    }
    download(fileName, content) {
        const a = window.document.createElement("a");
        a.href = window.URL.createObjectURL(this.getBlob(fileName, content));
        a.download = fileName;
        document.body.appendChild(a);
        a.click();
        document.body.removeChild(a);
    }
    open(fileName, content) {
        const blob = this.getBlob(fileName, content);
        const url = window.URL.createObjectURL(blob);
        window.open(url);
    }
    getBlobUrl(fileName, content) {
        return window.URL.createObjectURL(this.getBlob(fileName, content));
    }
    getBlob(fileName, content64) {
        const content = atob(content64);
        const byteArray = new Uint8Array(content.length);
        for (let i = 0; i < byteArray.length; i++)
            byteArray[i] = content.charCodeAt(i);
        return new Blob([byteArray], { type: paradigm_ui_web_shared_1.fileMimeType.get(fileName) });
    }
    getError(e) {
        switch (e.target["error"].code) {
            case e.target["error"].NOT_FOUND_ERR:
                return "File not found.";
            case e.target["error"].NOT_READABLE_ERR:
                return "File is not readable.";
            case e.target["error"].ABORT_ERR:
                return "Read operation was aborted.";
            case e.target["error"].SECURITY_ERR:
                return "File is in a locked state.";
            case e.target["error"].ENCODING_ERR:
                return "The file is too long to encode.";
            default:
                return "Can not read the file.";
        }
    }
    static factory(timeout) {
        return new FileManagementService_1(timeout);
    }
};
FileManagementService = FileManagementService_1 = (0, tslib_1.__decorate)([
    (0, service_1.Service)({
        name: "$pd-fileManagementService",
        dependencies: [angular_service_1.AngularServices.timeout],
    })
], FileManagementService);
exports.FileManagementService = FileManagementService;
//# sourceMappingURL=file-management.service.js.map