"use strict";
/*!
 * Paradigm Framework - AngularJS Wrapper
 * Copyright (c) 2017 Miracle Devs, Inc
 * Licensed under MIT (https://github.com/MiracleDevs/Paradigm.Web.Shared/blob/master/LICENSE)
 */
var LoggingService_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.LoggingService = exports.LogType = void 0;
const tslib_1 = require("tslib");
const base_service_1 = require("./base.service");
const paradigm_ui_web_shared_1 = require("@miracledevs/paradigm-ui-web-shared");
const service_1 = require("../decorators/service");
var LogType;
(function (LogType) {
    LogType[LogType["Trace"] = 0] = "Trace";
    LogType[LogType["Debug"] = 1] = "Debug";
    LogType[LogType["Information"] = 2] = "Information";
    LogType[LogType["Warning"] = 3] = "Warning";
    LogType[LogType["Error"] = 4] = "Error";
    LogType[LogType["Critical"] = 5] = "Critical";
})(LogType = exports.LogType || (exports.LogType = {}));
let LoggingService = LoggingService_1 = class LoggingService extends base_service_1.ServiceBase {
    constructor() {
        super();
        const message = "[{0}][{1}] - {3}{2}";
        this.messages = new Array();
        this.messages.push(message);
        this.messages.push(message);
        this.messages.push(message);
        this.messages.push(message);
        this.messages.push(message);
        this.messages.push(message);
        this.minimumLevel = LogType.Information;
    }
    /**
     * Sets the custom message for a given log type.
     * There are some predefined content placeholders the user can utilize
     * to configure the custom messages:
     * {0}: The time when the log was added.
     * {1}: The type of the log (Trace, Debug , Information, etc)
     * {2}: A custom tag value provided by the user.
     * {3}: The log message.
     */
    setCustomMessage(type, message) {
        if (type < 0 || type >= this.messages.length)
            throw new Error(LoggingService_1.typeNotRecognized);
        this.messages[type] = message;
    }
    /**
     * Sets the minimum log level.
     */
    setMinimumLevel(type) {
        if (type < 0 || type >= this.messages.length)
            throw new Error(LoggingService_1.typeNotRecognized);
        this.minimumLevel = type;
    }
    /**
     * Logs the specified message.
     */
    log(message, type = LogType.Trace, tag = null) {
        if (type < 0 || type >= this.messages.length)
            throw new Error(LoggingService_1.typeNotRecognized);
        if (type < this.minimumLevel)
            return;
        var formattedMessage = paradigm_ui_web_shared_1.StringExtensions.format(this.messages[type], paradigm_ui_web_shared_1.DateExtensions.format(new Date(), "hh:mm:ss"), LogType[type], tag, message);
        var c = console;
        switch (type) {
            case LogType.Trace:
                c.trace(formattedMessage);
                break;
            case LogType.Debug:
                c.debug(formattedMessage);
                break;
            case LogType.Information:
                c.info(formattedMessage);
                break;
            case LogType.Warning:
                c.warn(formattedMessage);
                break;
            case LogType.Error:
                c.error(formattedMessage);
                break;
            case LogType.Critical:
                c.error(formattedMessage);
                break;
        }
    }
    trace(message, tag = null) {
        this.log(message, LogType.Trace, tag);
    }
    debug(message, tag = null) {
        this.log(message, LogType.Debug, tag);
    }
    information(message, tag = null) {
        this.log(message, LogType.Information, tag);
    }
    warning(message, tag = null) {
        this.log(message, LogType.Warning, tag);
    }
    error(message, tag = null) {
        this.log(message, LogType.Error, tag);
    }
    critical(message, tag = null) {
        this.log(message, LogType.Critical, tag);
    }
    static factory() {
        return new LoggingService_1();
    }
};
LoggingService.typeNotRecognized = "The provided type is not recognized as a valida log type.";
LoggingService = LoggingService_1 = (0, tslib_1.__decorate)([
    (0, service_1.Service)({ name: "$pd-loggingService" })
], LoggingService);
exports.LoggingService = LoggingService;
//# sourceMappingURL=logging.service.js.map