"use strict";
/*!
 * Paradigm Framework - AngularJS Wrapper
 * Copyright (c) 2017 Miracle Devs, Inc
 * Licensed under MIT (https://github.com/MiracleDevs/Paradigm.Web.Shared/blob/master/LICENSE)
 */
var MessageBus_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.RegistrationToken = exports.MessageBusHandler = exports.MessageBus = void 0;
const tslib_1 = require("tslib");
const service_1 = require("../decorators/service");
const base_service_1 = require("./base.service");
const paradigm_ui_web_shared_1 = require("@miracledevs/paradigm-ui-web-shared");
const message_1 = require("../decorators/message");
let MessageBus = MessageBus_1 = class MessageBus extends base_service_1.ServiceBase {
    constructor() {
        super();
        this.handlers = new paradigm_ui_web_shared_1.Dictionary();
    }
    count() {
        return this.handlers.count();
    }
    isRegistered(messageType) {
        const type = messageType[message_1.messageTypeKey];
        return this.handlers.containsKey(type);
    }
    handlerCount(messageType) {
        const type = messageType[message_1.messageTypeKey];
        if (!this.handlers.containsKey(type))
            return 0;
        return this.handlers.get(type).count();
    }
    register(messageType, handler) {
        const type = messageType[message_1.messageTypeKey];
        if (!this.handlers.containsKey(type))
            this.handlers.add(type, new paradigm_ui_web_shared_1.ArrayList());
        const messageBusHandler = new MessageBusHandler(messageType, handler);
        this.handlers.get(type).add(messageBusHandler);
        return messageBusHandler.token;
    }
    unregister(token) {
        const type = token.type[message_1.messageTypeKey];
        if (!this.handlers.containsKey(type))
            return;
        const handler = this.handlers.get(type);
        handler.removeAll(x => x.token.guid === token.guid);
        if (!handler.any())
            this.handlers.remove(type);
    }
    send(message, token) {
        if (paradigm_ui_web_shared_1.ObjectExtensions.isNull(message))
            throw new Error("Can not send a null message.");
        if (paradigm_ui_web_shared_1.ObjectExtensions.isNull(message.constructor))
            throw new Error("Message does not have a constructor, and the system can not infer the type.");
        const type = message.constructor[message_1.messageTypeKey];
        if (!this.handlers.containsKey(type))
            return false;
        const handlers = this.handlers
            .get(type)
            .where(x => token == null || token.guid === x.token.guid)
            .select(x => x.handler);
        let accepted = false;
        for (let i = handlers.count() - 1; i >= 0; i--) {
            const handler = handlers.get(i);
            if (handler == null)
                continue;
            accepted = true;
            handler(message);
        }
        return accepted;
    }
    static factory() {
        return new MessageBus_1();
    }
};
MessageBus = MessageBus_1 = (0, tslib_1.__decorate)([
    (0, service_1.Service)({ name: "$pd-messageBus" })
], MessageBus);
exports.MessageBus = MessageBus;
class MessageBusHandler {
    constructor(type, handler) {
        this.innerHandler = handler;
        this.innerToken = new RegistrationToken(type);
    }
    get token() {
        return this.innerToken;
    }
    get handler() {
        return this.innerHandler;
    }
}
exports.MessageBusHandler = MessageBusHandler;
class RegistrationToken {
    constructor(type) {
        this.innerType = type;
        this.innerGuid = paradigm_ui_web_shared_1.Guid.new();
    }
    get type() {
        return this.innerType;
    }
    get guid() {
        return this.innerGuid;
    }
}
exports.RegistrationToken = RegistrationToken;
//# sourceMappingURL=message-bus.service.js.map