"use strict";
/*!
 * Paradigm Framework - AngularJS Wrapper
 * Copyright (c) 2017 Miracle Devs, Inc
 * Licensed under MIT (https://github.com/MiracleDevs/Paradigm.Web.Shared/blob/master/LICENSE)
 */
var ModalService_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.ModalParameters = exports.ModalInstance = exports.ModalService = void 0;
const tslib_1 = require("tslib");
const service_1 = require("../decorators/service");
const angular_service_1 = require("./angular.service");
const base_service_1 = require("./base.service");
const paradigm_ui_web_shared_1 = require("@miracledevs/paradigm-ui-web-shared");
const angular = require("angular");
const registrable_1 = require("../decorators/registrable");
const $ = require("jquery");
const transition_1 = require("../scripts/bootstrap/transition");
const modal_1 = require("../scripts/bootstrap/modal");
(0, transition_1.transition)($);
(0, modal_1.modal)($);
let ModalService = ModalService_1 = class ModalService extends base_service_1.ServiceBase {
    constructor($rootScope, $q, $http, $templateCache, $compile, $controller) {
        super();
        this.$rootScope = $rootScope;
        this.$q = $q;
        this.$http = $http;
        this.$templateCache = $templateCache;
        this.$compile = $compile;
        this.$controller = $controller;
        this.modals = new paradigm_ui_web_shared_1.Dictionary();
    }
    open(dialog, parameters, staticDialog = false, keyboard = true) {
        var dialogInfo = paradigm_ui_web_shared_1.ObjectExtensions.getTypeName(dialog) === "Function" ? dialog[registrable_1.registrableMetadataKey] : dialog;
        if (dialogInfo == null)
            throw new Error("The modal controller registration information is missing.");
        if (paradigm_ui_web_shared_1.ObjectExtensions.isNull(dialogInfo.template) && paradigm_ui_web_shared_1.ObjectExtensions.isNull(dialogInfo.templateUrl))
            throw new Error("Can not obtain a template for the modal. Use either template or templateUrl");
        var controllerAs = dialogInfo.controllerAs || "controller";
        var modalInstance = new ModalInstance(this, this.$q.defer());
        const template = !paradigm_ui_web_shared_1.ObjectExtensions.isNull(dialogInfo.template) ? dialogInfo.template : this.$templateCache.get(dialogInfo.templateUrl);
        // TODO: search for a better way to handle templateCache. $http probably have a handler to store the result on cache instead of storning the whole result object.
        if (template == null)
            this.$http.get(dialogInfo.templateUrl, { cache: this.$templateCache }).then(result => this.openModal(dialogInfo, parameters, modalInstance, result.data, staticDialog, keyboard));
        else
            this.openModal(dialogInfo, parameters, modalInstance, paradigm_ui_web_shared_1.ObjectExtensions.getTypeName(template).toLowerCase() === "string" ? template : template[1], staticDialog, keyboard);
        return modalInstance;
    }
    close(modalInstance, reason) {
        const modal = this.modals.get(modalInstance);
        if (modal == null)
            return;
        if (paradigm_ui_web_shared_1.ObjectExtensions.isNull(modal["modal"]))
            return;
        modal["modal"]("hide");
        modalInstance.deferred.reject(reason);
    }
    resolve(modalInstance, result) {
        const modal = this.modals.get(modalInstance);
        if (modal == null)
            return;
        if (paradigm_ui_web_shared_1.ObjectExtensions.isNull(modal["modal"]))
            return;
        modal["modal"]("hide");
        modalInstance.deferred.resolve(result);
    }
    openModal(dialogInfo, parameters, modalInstance, template, staticDialog, keyboard) {
        // create a new scope for the modal dialog.
        const scope = this.$rootScope.$new(true);
        const controllerParameters = {};
        controllerParameters[angular_service_1.AngularServices.scope] = scope;
        controllerParameters[paradigm_ui_web_shared_1.FunctionExtensions.getFunctionName(ModalInstance)] = modalInstance;
        controllerParameters[exports.ModalParameters] = parameters;
        // instantiate the modal controller.
        const controller = this.$controller(dialogInfo.controller, controllerParameters);
        // set the controller alias (by default will be controller).
        scope[dialogInfo.controllerAs] = controller;
        // create the modal DOM elements.
        const id = paradigm_ui_web_shared_1.Guid.new().value;
        const modalBody = angular.element(`<div class="modal fade" id="${id}" tabindex="-1" role="dialog" aria-labelledby="login-title"></div>`);
        modalBody.html(template);
        // compile the modal DOM for angular to resolve bindings and elements.
        var code = $(this.$compile(modalBody)(scope));
        // add the modal DOM to the page body.
        $("body").append(code);
        // register the modal inside the service.
        this.modals.add(modalInstance, code);
        const dialogOptions = {};
        if (staticDialog)
            dialogOptions["backdrop"] = "static";
        if (keyboard)
            dialogOptions["keyboard"] = keyboard;
        // open the MaterializeCSS modal.
        code["modal"](dialogOptions);
        // set the z-index of modal and backdrop
        const zIndex = this.modals.getValues().count() * 1050;
        code.css("z-index", zIndex);
        $(code[0].nextElementSibling).css("z-index", zIndex - 10);
        code.on("hidden.bs.modal", () => {
            modalInstance.deferred.reject("cancelled");
            this.removeModal(modalInstance, $(code), scope, controller);
        });
        controller.$onInit();
    }
    removeModal(modalInstance, modal, scope, controller) {
        this.modals.remove(modalInstance);
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(scope) && !paradigm_ui_web_shared_1.ObjectExtensions.isNull(controller)) {
            controller.$onDestroy();
            scope.$destroy();
        }
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(modal)) {
            modal.remove();
        }
        if (modalInstance.dispose != null) {
            modalInstance.dispose();
        }
    }
    static factory($rootScope, $q, $http, $templateCache, $compile, $controller) {
        return new ModalService_1($rootScope, $q, $http, $templateCache, $compile, $controller);
    }
};
ModalService = ModalService_1 = (0, tslib_1.__decorate)([
    (0, service_1.Service)({
        name: "$pd-modalService",
        dependencies: [angular_service_1.AngularServices.rootScope, angular_service_1.AngularServices.q, angular_service_1.AngularServices.http, angular_service_1.AngularServices.templateCache, angular_service_1.AngularServices.compile, angular_service_1.AngularServices.controller],
    })
], ModalService);
exports.ModalService = ModalService;
class ModalInstance {
    constructor(modalService, deferred) {
        this.modalService = modalService;
        this.deferred = deferred;
        this.promise = deferred.promise;
    }
    close(reason) {
        this.modalService.close(this, reason);
    }
    resolve(result) {
        this.modalService.resolve(this, result);
    }
}
exports.ModalInstance = ModalInstance;
exports.ModalParameters = "ModalParameters";
//# sourceMappingURL=modal.service.js.map